==> tine20-allinone_2020.08.8.tar.bz2: Crm/js/Crm-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Minden ügylet"

, "Default Lead List"
: "Alapértelmezett ügylet lista"

, "The default list for new leads"
: "Új ügyleteke alapértelmezett listája"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Tevékenységi szintek, amikről értesítést kérsz."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Alapértelmezett kedvenc"

, "The default favorite which is loaded on crm startup"
: "Alapértelmezett kedvenc, ami a Crm indításakor betöltődik"

, "New Lead"
: "Új ügylet"

, "Tags"
: "Címkék"

, "Lead name"
: "Ügylet név"

, "Responsible"
: "Felelős"

, "Partner"
: "Partner"

, "Customer"
: "Vásárló"

, "Leadstate"
: "Ügylet állapot"

, "Leadtype"
: "Ügylet típus"

, "Leadsource"
: "Ügylet forrás"

, "Probability"
: "Esély"

, "Turnover"
: "Bevétel"

, "Estimated end"
: "Becsült vég"

, "Probable Turnover"
: "Lehetséges bevétel"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Kapcsolat"

, "CRM Role"
: "CRM szerep"

, "Tasks"
: "Feladatok"

, "No Tasks to display"
: "Nincs megjeleníthető feladat"

, "Summary"
: "Összegzés"

, "Add a task..."
: "Feladat hozzáadása..."

, "Due Date"
: "Lejárati idő"

, "Priority"
: "Prioritás"

, "Percent"
: "Százalék"

, "Status"
: "Állapot"

, "Organizer"
: ""

, "Add new {0}"
: "Új {0} hozzáadása"

, "Unlink {0}"
: "{0} törlése"

, "Unlink selected {0}"
: "Kiválasztott {0} törlése"

, "Edit {0}"
: "{0} szerkesztése"

, "Edit selected {0}"
: "Kiválasztott {0} szerkesztése"

, "Please choose the Lead to add the contacts to"
: "Kérlek válaszd ki az ügyletet a kapcsolatok hozzáadásához"

, "Please select the attenders' role"
: "Kérlek válaszd ki a résztvevők szerepét"

, "Lead, Leads"
: [
  "Ügylet"
 ,"Ügyletek"

]
, "Select Lead"
: "Ügylet kiválasztása"

, "Role"
: "Szerep"

, "Select Role"
: "Szerep kiválasztása"

, "Adding {0} contacts to lead"
: "{0} kapcsolat hozzáadása az ügylethez"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Kezdet"

, "Change type to Customer"
: "Típus megváltoztatása Vevőre"

, "Change type to Responsible"
: "Típus megváltoztatása Felelősre"

, "Change type to Partner"
: "Típus megváltoztatása Partnerra"

, "Change contact type"
: "Kapcsolat típus megváltoztatása"

, "Search for Contacts to add ..."
: "Kapcsolat keresés hozzáadáshoz..."

, "Name"
: "Név"

, "Address"
: "Cím"

, "Data"
: "Adat"

, "Cellphone"
: "Mobil telefon"

, "End"
: "Vég"

, "You do not have the run right for the Tasks application or it is not activated."
: "Nincs futtatási jogod a Feladatok alkalmazáshoz vagy nincs aktiválva."

, "Products"
: "Termékek"

, "You do not have the run right for the Sales application or it is not activated."
: "Nincs futtatási jogod a Sales alkalmazáshoz vagy nincs aktiválva."

, "Enter lead name"
: ""

, "Expected turnover"
: "Elfogadható bevétel"

, "Description"
: "Leírás"

, "Enter description"
: "Leírás megadása"

, "lead list, lead lists"
: [
  "ügylet lista"
 ,"ügylet listák"

]
, "lead lists"
: "ügylet listák"

, "Quick Search"
: ""

, "Last Modified Time"
: "Utolsó módosítás ideje"

, "Last Modified By"
: "Utoljára módosította"

, "Creation Time"
: "Készítés ideje"

, "Created By"
: "Készítette"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Termék"

, "Price"
: "Ár"

, "Quantity"
: "Mennyiség"

, "Search for Products to add ..."
: "Termék keresése hozzáadáshoz..."

, "All leads I have read grants for"
: "Minden ügylet amikhez olvasási engedélyem van"

, "Last modified by me"
: "Utolsó általam módosított"

, "All leads that I have last modified"
: "Minden ügylet amit utoljára én módosítottam"

, "My leads"
: "Saját ügyleteim"

, "All leads that I am responsible for"
: "Minden ügylet amiért én vagyok a felelős"

, "Leads with overdue tasks"
: "Ügyletek lejárt feladatokkal"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "nyitott"

, "contacted"
: "kapcsolatban"

, "waiting for feedback"
: "visszajelzésre vár"

, "quote sent"
: "árajánlat elküldve"

, "accepted"
: "elfogadva"

, "lost"
: "elveszítve"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Viszonteladó"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Állapot"

, "Source"
: "Forrás"

, "Scheduled end"
: "Tervezett vég"

, "Folder"
: "Mappa"

, "Updated by"
: "Frissítette"

, "Updated Fields:"
: "Frissített mezők:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Ügylet %s megváltozott"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Ügylet %s elkészült"

, "Task"
: ""

, "Lead Data"
: "Ügylet adatok"

, "End Scheduled"
: "Tervezett vég"

, "Contacts"
: "Kapcsolatok"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "low"
: "alacsony"

, "normal"
: "normál"

, "high"
: "magas"

, "urgent"
: "sürgős"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "megosztott ügylet mappák kezelése"

, "Create new shared lead folders"
: "Új megosztott ügylet mappa létrehozása"

, "manage shared leads favorites"
: "kedvenc megosztott ügyletek kezelése"

, "Create or update shared leads favorites"
: "Kedvenc megosztott ügyletek hozzáadása vagy frissítése"




, "Lead"
: "Ügylet"

, "lead list"
: "ügylet lista"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Vásárló"

, "Partner"
: "Partner"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Állapot"

, "Start"
: "Kezdet"

, "Estimated end"
: "Becsült vég"

, "Leadtype"
: "Ügylet típus"

, "Leadsource"
: "Ügylet forrás"

, "Tags"
: "Címkék"

, "Lead name"
: "Ügylet név"

, "Responsible"
: "Felelős"

, "Leadstate"
: "Ügylet állapot"

, "Probability"
: "Esély"

, "Turnover"
: "Bevétel"

, "End"
: "Vég"

, "Probable Turnover"
: "Lehetséges bevétel"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Add new {0}"
: "Új {0} hozzáadása"

, "Unlink {0}"
: "{0} törlése"

, "Unlink selected {0}"
: "Kiválasztott {0} törlése"

, "Edit {0}"
: "{0} szerkesztése"

, "Edit selected {0}"
: "Kiválasztott {0} szerkesztése"

, "New Lead"
: "Új ügylet"

, "Products"
: "Termékek"

, "Product"
: "Termék"

, "Description"
: "Leírás"

, "Price"
: "Ár"

, "Quantity"
: "Mennyiség"

, "Search for Products to add ..."
: "Termék keresése hozzáadáshoz..."

, "1"
: ""

, "Notifications are disabled"
: ""

, "Send Notification?"
: ""

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "Tasks"
: "Feladatok"

, "You do not have the run right for the Tasks application or it is not activated."
: "Nincs futtatási jogod a Feladatok alkalmazáshoz vagy nincs aktiválva."

, "You do not have the run right for the Sales application or it is not activated."
: "Nincs futtatási jogod a Sales alkalmazáshoz vagy nincs aktiválva."

, "Lead, Leads"
: [
  "Ügylet"
 ,"Ügyletek"

]
, "Enter lead name"
: ""

, "Expected turnover"
: "Elfogadható bevétel"

, "Enter description"
: "Leírás megadása"

, "lead list, lead lists"
: [
  "ügylet lista"
 ,"ügylet listák"

]
, "lead lists"
: "ügylet listák"

, "Quick Search"
: ""

, "Last Modified Time"
: "Utolsó módosítás ideje"

, "Last Modified By"
: "Utoljára módosította"

, "Creation Time"
: "Készítés ideje"

, "Created By"
: "Készítette"

, "X Lead"
: ""

, "read-only"
: ""

, "Archived"
: ""

, "Contact"
: "Kapcsolat"

, "CRM Role"
: "CRM szerep"

, "Change type to Customer"
: "Típus megváltoztatása Vevőre"

, "Change type to Responsible"
: "Típus megváltoztatása Felelősre"

, "Change type to Partner"
: "Típus megváltoztatása Partnerra"

, "Change contact type"
: "Kapcsolat típus megváltoztatása"

, "Search for Contacts to add ..."
: "Kapcsolat keresés hozzáadáshoz..."

, "Name"
: "Név"

, "Address"
: "Cím"

, "Data"
: "Adat"

, "Cellphone"
: "Mobil telefon"

, "Role"
: "Szerep"

, "Please choose the Lead to add the contacts to"
: "Kérlek válaszd ki az ügyletet a kapcsolatok hozzáadásához"

, "Please select the attenders' role"
: "Kérlek válaszd ki a résztvevők szerepét"

, "Select Lead"
: "Ügylet kiválasztása"

, "Select Role"
: "Szerep kiválasztása"

, "Adding {0} contacts to lead"
: "{0} kapcsolat hozzáadása az ügylethez"

, "No Tasks to display"
: "Nincs megjeleníthető feladat"

, "Summary"
: "Összegzés"

, "Add a task..."
: "Feladat hozzáadása..."

, "Due Date"
: "Lejárati idő"

, "Priority"
: "Prioritás"

, "Percent"
: "Százalék"

, "Organizer"
: ""

, "All leads"
: "Minden ügylet"

, "Default Lead List"
: "Alapértelmezett ügylet lista"

, "The default list for new leads"
: "Új ügyleteke alapértelmezett listája"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Tevékenységi szintek, amikről értesítést kérsz."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Default Favorite"
: "Alapértelmezett kedvenc"

, "The default favorite which is loaded on crm startup"
: "Alapértelmezett kedvenc, ami a Crm indításakor betöltődik"

, "controls sending notification of Leads"
: ""

, "send notification)description"
: ""

, "send notification to all access container"
: ""

, "send notification to responsible"
: ""

, "send notification to responsible)description"
: ""

, "send notification to customer"
: ""

, "send notification to partner"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "nyitott"

, "contacted"
: "kapcsolatban"

, "waiting for feedback"
: "visszajelzésre vár"

, "quote sent"
: "árajánlat elküldve"

, "accepted"
: "elfogadva"

, "lost"
: "elveszítve"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Viszonteladó"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Lead Notification Confirmation"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead Data"
: "Ügylet adatok"

, "End Scheduled"
: "Tervezett vég"

, "Contacts"
: "Kapcsolatok"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "low"
: "alacsony"

, "normal"
: "normál"

, "high"
: "magas"

, "urgent"
: "sürgős"

, "CSV all data"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "GENDER_Lead"
: ""

, "Show Closed"
: ""

, "Task"
: ""

, "State"
: "Állapot"

, "Source"
: "Forrás"

, "Scheduled end"
: "Tervezett vég"

, "Folder"
: "Mappa"

, "Updated by"
: "Frissítette"

, "Updated Fields:"
: "Frissített mezők:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Ügylet %s megváltozott"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Ügylet %s elkészült"

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: ""

, "All leads I have read grants for"
: "Minden ügylet amikhez olvasási engedélyem van"

, "Last modified by me"
: "Utolsó általam módosított"

, "All leads that I have last modified"
: "Minden ügylet amit utoljára én módosítottam"

, "My leads"
: "Saját ügyleteim"

, "All leads that I am responsible for"
: "Minden ügylet amiért én vagyok a felelős"

, "Leads with overdue tasks"
: "Ügyletek lejárt feladatokkal"

, "manage shared lead folders"
: "megosztott ügylet mappák kezelése"

, "Create new shared lead folders"
: "Új megosztott ügylet mappa létrehozása"

, "manage shared leads favorites"
: "kedvenc megosztott ügyletek kezelése"

, "Create or update shared leads favorites"
: "Kedvenc megosztott ügyletek hozzáadása vagy frissítése"




, "Lead"
: "Ügylet"

, "lead list"
: "ügylet lista"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
